pub struct PublicIdentity(/* private fields */);Expand description
Public identity
Making this public (include the public key and the chain code) allows for anyone to derive the public key associated to the different schemes (signing or key exchange).
This key cannot be used for anything else, we restrict its usage to public derivation of different keys
Implementations