Seed

Struct Seed 

pub struct Seed(/* private fields */);

Implementations

Source

impl Seed

pub const SIZE: usize = 32usize

pub fn generate<RNG>(rng: &mut RNG) -> Seed
where RNG: RngCore + CryptoRng,

Generate a random see with the given Cryptographically secure Random Number Generator (RNG).

This is useful to generate one time only Seed that does not need to be remembered or saved.

pub fn derive_from_key<K, P>(key: K, password: P) -> Seed
where K: AsRef<[u8]>, P: AsRef<[u8]>,

it is possible to derive the Seed from a given key

the key may be given by a secure hardware or simply be a mnemonic phrase given by a user and a password.

It is possible, but not recommended, that the password is left empty. However, the key needs to be large enough to generate enough entropy for the derived seed.

pub fn into_rand_chacha(self) -> ChaCha20Rng

use this to seed a ChaCha RNG

then you can use the RNG to create new private key. This is an handy way to derive a private key from a key and a password (or an HSM and a password?)