pub struct SharedSecret(/* private fields */);Expand description
A Shared Secret that can be used to generate a symmetric key
Implementations
pub const SIZE: usize = 32usize
Sourcepub const fn new(shared_secret: [u8; 32]) -> SharedSecret
pub const fn new(shared_secret: [u8; 32]) -> SharedSecret
create a shared secret from the given bytes
To use only as a constructor if receiving the shared secret from a HSM or a secure enclave. Otherwise use the exchange function on the associate private/secret keys